@@ -40,6 +40,8 @@ int Help()
     TEXTOUT("                    Full information Display with HTML tags");
     TEXTOUT("--Output=XML");
     TEXTOUT("                    Full information Display with XML tags");
+    TEXTOUT("--Output=EBUCore");
+    TEXTOUT("                    Full information Display with EBUCore compliant XML tags");
     TEXTOUT("--Output=...y");
     TEXTOUT("                    Template defined information Display");
     TEXTOUT("--Info-Parameters");
