@@ -126,6 +126,18 @@ int Preferences::Config_Load()
 
     RefreshFilesList(Prefs_Language);
     Load(Prefs_Language, Config(FolderNames[Prefs_Language]));
+	{
+		//Now we prioritize language files in the app dir instead of the language files in the user dir
+		//TODO: forbid edit of default language files
+		ZenLib::Ztring BaseFolderOld=BaseFolder;
+		BaseFolder=Application->ExeName.c_str();
+		BaseFolder=BaseFolder.substr(0, BaseFolder.rfind(__T("\\"))+1);
+		if (!Dir::Exists(BaseFolder+__T("Plugin")))
+			Dir::Create(BaseFolder+__T("Plugin"));
+		BaseFolder+=__T("Plugin\\");
+		Load(Prefs_Language, Config(FolderNames[Prefs_Language]));
+		BaseFolder=BaseFolderOld;
+	}
     RefreshFilesList(Prefs_Sheet);
     Load(Prefs_Sheet, Config(FolderNames[Prefs_Sheet]));
     RefreshFilesList(Prefs_Tree);
@@ -510,6 +522,7 @@ int Preferences::ExplorerShell()
         ".m4b;mpeg4File\r\n"
         ".m4v;mpeg4File\r\n"
         ".mac;APEFile\r\n"
+        ".mk3d;MK3DFile\r\n"
         ".mka;MKAFile\r\n"
         ".mks;MKSFile\r\n"
         ".mkv;MKVFile\r\n"
@@ -1099,6 +1112,7 @@ int Preferences::ShellToolTip()
         ".m4v;mpeg4File\r\n"
         ".mac;APEFile\r\n"
         ".mlp;MLPFile\r\n"
+        ".mk3d;MK3DFile\r\n"
         ".mka;MKAFile\r\n"
         ".mks;MKSFile\r\n"
         ".mkv;MKVFile\r\n"
